@@ -18,7 +18,7 @@
 """Sample configuration generator
 
 Tool for generating a sample configuration file. See
-../doc/source/generator.rst for details.
+../doc/source/cli/generator.rst for details.
 
 .. versionadded:: 1.4
 """
@@ -748,7 +748,13 @@ def main(args=None):
     logging.basicConfig(level=logging.WARN)
     conf = cfg.ConfigOpts()
     register_cli_opts(conf)
-    conf(args, version=version)
+    try:
+        conf(args, version=version)
+    except cfg.RequiredOptError:
+        conf.print_help()
+        if not sys.argv[1:]:
+            raise SystemExit
+        raise
     generate(conf)
 
 
